@@ -96,7 +96,7 @@ class ReportPortal:
 
     def start_keyword(self, name, attributes):
         parent_type = 'SUITE' if not self.items else 'TEST'
-        parent_item_id = self.items[-1][0] if self.items else None
+        parent_item_id = self.items[-1][0]
         kwd = Keyword(name=name, parent_type=parent_type, attributes=attributes)
         self._logger.debug("ReportPortal - Start Keyword: {0}".format(attributes))
         self.items.append((
@@ -117,8 +117,6 @@ class ReportPortal:
         else:
             msg = LogMessage(message["message"])
             msg.level = message["level"]
-            if "attachment" in message:
-                msg.attachment = message["attachment"]
 
         msg.item_id = self.items[-1][0]
         self._logger.debug("ReportPortal - Log Message: {0}".format(message))
