@@ -12,7 +12,6 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-import os
 import sys
 
 from robot.errors import DataError
@@ -35,10 +34,12 @@ class RpBot(object):
     def run(self):
         try:
             for xml_file in self._options.file_paths:
-                self._parser.xml_to_db(xml_file, base_dir=os.path.dirname(xml_file))
+                self._parser.xml_to_db(xml_file)
         except DataError as message:
             sys.stderr.write('rpbot: error: Invalid XML: %s\n\n' % message)
             exit(1)
+        # finally:
+        #     self._db.close()
 
 
 if __name__ == '__main__':
